@@ -66,23 +66,28 @@
 
 /**
  * anjuta_project_property_new:
- * name: (transfer none):
- * value: (transfer none):
- * native: (allow-none) (transfer none):
+ * @id: (transfer none):
+ * @name: (transfer none):
+ * @value: (transfer none):
+ * @native: (allow-none) (transfer none):
  *
  * Returns: (transfer full):
  */
 AnjutaProjectProperty *
-anjuta_project_property_new (const gchar *name, AnjutaProjectValueType type,
+anjuta_project_property_new (const gchar* id, const gchar *name, AnjutaProjectValueType type,
                              const gchar *value, AnjutaProjectProperty *native)
 {
 	AnjutaProjectProperty *prop = g_slice_new0(AnjutaProjectProperty);
+	prop->id = g_strdup (id);
 	prop->name = g_strdup (name);
 	prop->type = type;
 	prop->value = g_strdup (value);
-	prop->native = native;
-	prop->flags = native->flags;
-	prop->detail = native->detail;
+
+	if (native != NULL) {
+		prop->native = native;
+		prop->flags = native->flags;
+		prop->detail = native->detail;
+	}
 	
 	return prop;
 }
@@ -90,7 +95,7 @@ anjuta_project_property_new (const gchar *name, AnjutaProjectValueType type,
 AnjutaProjectProperty *
 anjuta_project_property_copy (AnjutaProjectProperty *prop)
 {
-	return anjuta_project_property_new (prop->name, prop->type,
+	return anjuta_project_property_new (prop->id, prop->name, prop->type,
 	                                    prop->value, prop->native);
 }
 
@@ -124,6 +129,11 @@ anjuta_project_property_get_type (void)
 /* Moving in tree functions
  *---------------------------------------------------------------------------*/
 
+/**
+ * anjuta_project_node_parent:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_parent(AnjutaProjectNode *node)
 {
@@ -132,6 +142,11 @@ anjuta_project_node_parent(AnjutaProjectNode *node)
 	return node->parent;
 }
 
+/**
+ * anjuta_project_node_root:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_root (AnjutaProjectNode *node)
 {
@@ -145,6 +160,12 @@ anjuta_project_node_root (AnjutaProjectNode *node)
 	return node;
 }
 
+/**
+ * anjuta_project_node_first_child:
+ *
+ * Returns: (transfer none):
+ */
+
 AnjutaProjectNode *
 anjuta_project_node_first_child(AnjutaProjectNode *node)
 {
@@ -153,6 +174,12 @@ anjuta_project_node_first_child(AnjutaProjectNode *node)
 	return node->children;
 }
 
+/**
+ * anjuta_project_node_last_child:
+ *
+ * Returns: (transfer none):
+ */
+
 AnjutaProjectNode *
 anjuta_project_node_last_child(AnjutaProjectNode *node)
 {
@@ -166,6 +193,11 @@ anjuta_project_node_last_child(AnjutaProjectNode *node)
   return node;
 }
 
+/**
+ * anjuta_project_node_next_sibling:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_next_sibling (AnjutaProjectNode *node)
 {
@@ -174,6 +206,11 @@ anjuta_project_node_next_sibling (AnjutaProjectNode *node)
 	return node->next;
 }
 
+/**
+ * anjuta_project_node_prev_sibling:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_prev_sibling (AnjutaProjectNode *node)
 {
@@ -182,6 +219,11 @@ anjuta_project_node_prev_sibling (AnjutaProjectNode *node)
 	return node->prev;
 }
 
+/**
+ * anjuta_project_node_nth_child:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *anjuta_project_node_nth_child (AnjutaProjectNode *node, guint n)
 {
 	g_return_val_if_fail (node != NULL, NULL);
@@ -244,6 +286,12 @@ anjuta_project_node_pre_order_traverse (AnjutaProjectNode *node, AnjutaProjectNo
 }
 
 
+/**
+ * anjuta_project_node_traverse:
+ * @func: (scope call):
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_traverse (AnjutaProjectNode *node, GTraverseType order, AnjutaProjectNodeTraverseFunc func, gpointer data)
 {
@@ -262,6 +310,12 @@ anjuta_project_node_traverse (AnjutaProjectNode *node, GTraverseType order, Anju
 	}
 }
 
+/**
+ * anjuta_project_node_children_traverse:
+ * @func: (scope call):
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_children_traverse (AnjutaProjectNode *node, AnjutaProjectNodeTraverseFunc func, gpointer data)
 {
@@ -321,7 +375,10 @@ anjuta_project_node_pre_order_foreach (AnjutaProjectNode *node, AnjutaProjectNod
 	}
 }
 
-
+/**
+ * anjuta_project_node_foreach:
+ * @func: (scope call):
+ */
 void
 anjuta_project_node_foreach (AnjutaProjectNode *node, GTraverseType order, AnjutaProjectNodeForeachFunc func, gpointer data)
 {
@@ -342,6 +399,10 @@ anjuta_project_node_foreach (AnjutaProjectNode *node, GTraverseType order, Anjut
 	}
 }
 
+/**
+ * anjuta_project_node_children_foreach:
+ * @func: (scope call):
+ */
 void
 anjuta_project_node_children_foreach (AnjutaProjectNode *node, AnjutaProjectNodeForeachFunc func, gpointer data)
 {
@@ -360,6 +421,25 @@ anjuta_project_node_children_foreach (AnjutaProjectNode *node, AnjutaProjectNode
 	}
 }
 
+/**
+ * anjuta_project_node_parent_type:
+ *
+ * Returns: (transfer none):
+ */
+AnjutaProjectNode *
+anjuta_project_node_parent_type(AnjutaProjectNode *node,  AnjutaProjectNodeType type)
+{
+	do
+	{
+		node = anjuta_project_node_parent (node);
+		if (node == NULL) break;
+	}
+	while (anjuta_project_node_get_node_type (node) != type);
+
+	return node;
+}
+
+
 
 /* Debugging functions
  *---------------------------------------------------------------------------*/
@@ -534,8 +614,6 @@ anjuta_project_node_insert_after (AnjutaProjectNode *parent, AnjutaProjectNode *
 
 /**
  * anjuta_project_node_remove:
- * @parent:
- * @sibling: (allow-none) (transfer none):
  * @node: (transfer none):
  *
  * Returns: (transfer full):
@@ -560,12 +638,22 @@ anjuta_project_node_remove (AnjutaProjectNode *node)
 	return node;
 }
 
+/**
+ * anjuta_project_node_prepend:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_prepend (AnjutaProjectNode *parent, AnjutaProjectNode *node)
 {
 	return anjuta_project_node_insert_before (parent, parent->children, node);	
 }
 
+/**
+ * anjuta_project_node_append:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
 anjuta_project_node_append (AnjutaProjectNode *parent, AnjutaProjectNode *node)
 { 
@@ -605,6 +693,11 @@ anjuta_project_node_get_name (const AnjutaProjectNode *node)
 	return node->name;
 }
 
+/**
+ * anjuta_project_node_get_file:
+ *
+ * Returns: (transfer none):
+ */
 GFile*
 anjuta_project_node_get_file (const AnjutaProjectNode *node)
 {
@@ -636,12 +729,22 @@ anjuta_project_node_get_file (const AnjutaProjectNode *node)
 	return node->file;		
 }
 
+/**
+ * anjuta_project_node_get_custom_properties:
+ *
+ * Returns: (transfer none) (element-type Anjuta.ProjectProperty):
+ */
 GList *
 anjuta_project_node_get_custom_properties (AnjutaProjectNode *node)
 {
 	return node->custom_properties;
 }
 
+/**
+ * anjuta_project_node_get_native_properties:
+ *
+ * Returns: (transfer none) (element-type Anjuta.ProjectProperty):
+ */
 GList *
 anjuta_project_node_get_native_properties (AnjutaProjectNode *node)
 {
@@ -660,6 +763,11 @@ find_property (gconstpointer item, gconstpointer data)
 	return prop_a != prop_b;
 }
 
+/**
+ * anjuta_project_node_get_property:
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectProperty *
 anjuta_project_node_get_property (AnjutaProjectNode *node, AnjutaProjectProperty *property)
 {
@@ -731,6 +839,13 @@ anjuta_project_node_clear_state (AnjutaProjectNode *node, AnjutaProjectNodeState
 	return TRUE;
 }
 
+/**
+ * anjuta_project_node_insert_property:
+ * @property: (transfer full):
+ *
+ * Returns: (transfer none):
+ */
+
 AnjutaProjectProperty *
 anjuta_project_node_insert_property (AnjutaProjectNode *node, AnjutaProjectProperty *native, AnjutaProjectProperty *property)
 {
@@ -799,8 +914,14 @@ anjuta_project_group_compare (AnjutaProjectNode *node, gpointer data)
 	}
 }
 
+/**
+ * anjuta_project_node_get_group_from_file:
+ * @func: (scope call):
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
-anjuta_project_group_get_node_from_file (const AnjutaProjectNode *root, GFile *directory)
+anjuta_project_node_get_group_from_file (const AnjutaProjectNode *root, GFile *directory)
 {
 	AnjutaProjectNode *node;
 
@@ -849,8 +970,14 @@ anjuta_project_source_compare (AnjutaProjectNode *node, gpointer data)
 	}
 }
 
+/**
+ * anjuta_project_node_get_source_from_file:
+ * @func: (scope call):
+ *
+ * Returns: (transfer none):
+ */
 AnjutaProjectNode *
-anjuta_project_source_get_node_from_file (const AnjutaProjectNode *parent, GFile *file)
+anjuta_project_node_get_source_from_file (const AnjutaProjectNode *parent, GFile *file)
 {
 	AnjutaProjectNode *node;
 
@@ -1135,8 +1262,8 @@ anjuta_project_node_info_type (const AnjutaProjectNodeInfo *info)
 
 /**
  * anjuta_project_node_info_new:
- * name: (transfer none):
- * mime_type: (transfer none):
+ * @name: (transfer none):
+ * @mime_type: (transfer none):
  *
  * Returns: (transfer full):
  */
